cvs: php4 /ext/cybercash cyberlib.php /ext/standard basic_functions.c php_string.h string.c
| From: | Jeroen van Wolffelaar | Date: | Sun, 23 Sep 2001 18:32:47 +0000 |
| Subject: | cvs: php4 /ext/cybercash cyberlib.php /ext/standard basic_functions.c php_string.h string.c | ||
| Groups: | php.cvs | ||
| Request: | Send a blank email to php-cvs+get-7517@lists.php.net to get a copy of this message | ||
jeroen Sun Sep 23 14:32:47 2001 EDT
Modified files:
/php4/ext/cybercash cyberlib.php
/php4/ext/standard basic_functions.c php_string.h string.c
Log:
Make chop the alias and rtrim the main function, in order to get automagically
generated alias-listings correct.
Index: php4/ext/cybercash/cyberlib.php
diff -u php4/ext/cybercash/cyberlib.php:1.5 php4/ext/cybercash/cyberlib.php:1.6
--- php4/ext/cybercash/cyberlib.php:1.5 Wed Mar 1 02:03:33 2000
+++ php4/ext/cybercash/cyberlib.php Sun Sep 23 14:32:46 2001
@@ -36,7 +36,7 @@
$more=list($key,$val)=each($CCNVList);
while(!$done)
{
- $pairs.=chop($key)."=".urlencode(chop($val));
+ $pairs.=rtrim($key)."=".urlencode(rtrim($val));
$more=list($key,$val)=each($CCNVList);
if($more)
Index: php4/ext/standard/basic_functions.c
diff -u php4/ext/standard/basic_functions.c:1.400 php4/ext/standard/basic_functions.c:1.401
--- php4/ext/standard/basic_functions.c:1.400 Fri Sep 21 21:39:14 2001
+++ php4/ext/standard/basic_functions.c Sun Sep 23 14:32:46 2001
@@ -17,7 +17,7 @@
+----------------------------------------------------------------------+
*/
-/* $Id: basic_functions.c,v 1.400 2001/09/22 01:39:14 jeroen Exp $ */
+/* $Id: basic_functions.c,v 1.401 2001/09/23 18:32:46 jeroen Exp $ */
#include "php.h"
#include "php_main.h"
@@ -333,7 +333,7 @@
PHP_FE(strtr, NULL)
PHP_FE(addslashes, NULL)
PHP_FE(addcslashes, NULL)
- PHP_FE(chop, NULL)
+ PHP_FE(rtrim, NULL)
PHP_FE(str_replace, NULL)
PHP_FE(str_repeat, NULL)
PHP_FE(count_chars, NULL)
@@ -359,7 +359,7 @@
PHP_FE(ord, NULL)
PHP_FE(parse_str, second_arg_force_ref)
PHP_FE(str_pad, NULL)
- PHP_FALIAS(rtrim, chop, NULL)
+ PHP_FALIAS(chop, rtrim, NULL)
PHP_FALIAS(strchr, strstr, NULL)
PHP_NAMED_FE(sprintf, PHP_FN(user_sprintf), NULL)
PHP_NAMED_FE(printf, PHP_FN(user_printf), NULL)
Index: php4/ext/standard/php_string.h
diff -u php4/ext/standard/php_string.h:1.52 php4/ext/standard/php_string.h:1.53
--- php4/ext/standard/php_string.h:1.52 Sun Sep 9 08:55:48 2001
+++ php4/ext/standard/php_string.h Sun Sep 23 14:32:46 2001
@@ -17,7 +17,7 @@
+----------------------------------------------------------------------+
*/
-/* $Id: php_string.h,v 1.52 2001/09/09 12:55:48 derick Exp $ */
+/* $Id: php_string.h,v 1.53 2001/09/23 18:32:46 jeroen Exp $ */
/* Synced with php 3.0 revision 1.43 1999-06-16 [ssb] */
@@ -27,7 +27,7 @@
PHP_FUNCTION(strspn);
PHP_FUNCTION(strcspn);
PHP_FUNCTION(str_replace);
-PHP_FUNCTION(chop);
+PHP_FUNCTION(rtrim);
PHP_FUNCTION(trim);
PHP_FUNCTION(ltrim);
PHP_FUNCTION(soundex);
Index: php4/ext/standard/string.c
diff -u php4/ext/standard/string.c:1.242 php4/ext/standard/string.c:1.243
--- php4/ext/standard/string.c:1.242 Fri Sep 21 17:59:23 2001
+++ php4/ext/standard/string.c Sun Sep 23 14:32:46 2001
@@ -18,7 +18,7 @@
+----------------------------------------------------------------------+
*/
-/* $Id: string.c,v 1.242 2001/09/21 21:59:23 hholzgra Exp $ */
+/* $Id: string.c,v 1.243 2001/09/23 18:32:46 jeroen Exp $ */
/* Synced with php 3.0 revision 1.193 1999-06-16 [ssb] */
@@ -540,13 +540,13 @@
}
/* }}} */
-/* {{{ proto string rtrim(string str [, string character_mask])
- An alias for chop */
+/* {{{ proto string chop(string str [, string character_mask])
+ An alias for rtrim */
/* }}} */
/* {{{ proto string chop(string str [, string character_mask])
Removes trailing whitespace */
-PHP_FUNCTION(chop)
+PHP_FUNCTION(rtrim)
{
zval **str;
zval **what = NULL;
@@ -540,13 +540,13 @@
/* }}} */
-/* {{{ proto string chop(string str [, string character_mask])
+/* {{{ proto string rtrim(string str [, string character_mask])
Removes trailing whitespace */